==========
riffaraffa
==========


.. image:: https://img.shields.io/pypi/v/riffaraffa.svg
        :target: https://pypi.python.org/pypi/riffaraffa

.. image:: https://www.repostatus.org/badges/latest/wip.svg
    :alt: Project Status: WIP – Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.
    :target: https://www.repostatus.org/#wip

.. image:: https://travis-ci.com/robertopreste/riffaraffa.svg?branch=master
        :target: https://travis-ci.com/robertopreste/riffaraffa

.. image:: https://circleci.com/gh/robertopreste/riffaraffa.svg?style=svg
        :target: https://circleci.com/gh/robertopreste/riffaraffa

.. image:: https://codecov.io/gh/robertopreste/riffaraffa/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/robertopreste/riffaraffa

.. image:: https://readthedocs.org/projects/riffaraffa/badge/?version=latest
        :target: https://riffaraffa.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/robertopreste/riffaraffa/shield.svg
     :target: https://pyup.io/repos/github/robertopreste/riffaraffa/
     :alt: Updates

.. image:: https://pyup.io/repos/github/robertopreste/riffaraffa/python-3-shield.svg
     :target: https://pyup.io/repos/github/robertopreste/riffaraffa/
     :alt: Python 3



.. image:: https://pepy.tech/badge/riffaraffa
    :target: https://pepy.tech/project/riffaraffa
    :alt: Downloads

.. image:: https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg
   :target: https://saythanks.io/to/robertopreste


La riffa e la raffa python package.


* Free software: MIT license
* Documentation: https://riffaraffa.readthedocs.io
* GitHub repo: https://github.com/robertopreste/riffaraffa


Features
========

* Show available movies
* Randomly choose a movie to watch
* Add a new movie to the list

Usage
=====

Commands::

  add     Add a movie to the database.
  choose  Choose a movie from the list.
  show    Show available movies from the database.


Installation
============

``pip install riffaraffa``

Credits
=======

This package was created with Cookiecutter_ and the `cc-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`cc-pypackage`: https://github.com/robertopreste/cc-pypackage
.. _Usage: https://riffaraffa.readthedocs.io/en/latest/usage.html
.. _Installation: https://riffaraffa.readthedocs.io/en/latest/installation.html
